@@ -45,6 +45,7 @@ from .models.dla import *
 from .models.msdnet import *
 from .models.fishnet import *
 from .models.espnetv2 import *
+from .models.dicenet import *
 from .models.hrnet import *
 from .models.vovnet import *
 from .models.selecsls import *
@@ -117,9 +118,22 @@ from .models.pspnet import *
 from .models.deeplabv3 import *
 from .models.icnet import *
 from .models.fastscnn import *
+from .models.cgnet import *
+from .models.dabnet import *
 from .models.sinet import *
 from .models.bisenet import *
 from .models.danet import *
+from .models.fpenet import *
+from .models.contextnet import *
+from .models.lednet import *
+from .models.esnet import *
+from .models.edanet import *
+from .models.enet import *
+from .models.erfnet import *
+from .models.linknet import *
+from .models.segnet import *
+from .models.unet import *
+from .models.sqnet import *
 
 from .models.alphapose_coco import *
 from .models.simplepose_coco import *
@@ -132,11 +146,16 @@ from .models.prnet import *
 from .models.centernet import *
 from .models.lffd import *
 
+from .models.pfpcnet import *
 from .models.voca import *
 from .models.nvpattexp import *
 
 from .models.superpointnet import *
 
+from .models.jasper import *
+from .models.jasperdr import *
+from .models.quartznet import *
+
 # from .models.others.oth_pose_resnet import *
 # from .models.others.oth_lwopenpose2d import *
 # from .models.others.oth_lwopenpose3d import *
@@ -148,6 +167,7 @@ from .models.superpointnet import *
 
 # from .models.others.oth_tresnet import *
 # from .models.tresnet import *
+# from .models.others.oth_dabnet import *
 
 __all__ = ['get_model']
 
@@ -490,6 +510,15 @@ _models = {
     'espnetv2_w3d2': espnetv2_w3d2,
     'espnetv2_w2': espnetv2_w2,
 
+    'dicenet_wd5': dicenet_wd5,
+    'dicenet_wd2': dicenet_wd2,
+    'dicenet_w3d4': dicenet_w3d4,
+    'dicenet_w1': dicenet_w1,
+    'dicenet_w5d4': dicenet_w5d4,
+    'dicenet_w3d2': dicenet_w3d2,
+    'dicenet_w7d8': dicenet_w7d8,
+    'dicenet_w2': dicenet_w2,
+
     'hrnet_w18_small_v1': hrnet_w18_small_v1,
     'hrnet_w18_small_v2': hrnet_w18_small_v2,
     'hrnetv2_w18': hrnetv2_w18,
@@ -1050,6 +1079,9 @@ _models = {
 
     'fastscnn_cityscapes': fastscnn_cityscapes,
 
+    'cgnet_cityscapes': cgnet_cityscapes,
+    'dabnet_cityscapes': dabnet_cityscapes,
+
     'sinet_cityscapes': sinet_cityscapes,
 
     'bisenet_resnet18_celebamaskhq': bisenet_resnet18_celebamaskhq,
@@ -1057,6 +1089,28 @@ _models = {
     'danet_resnetd50b_cityscapes': danet_resnetd50b_cityscapes,
     'danet_resnetd101b_cityscapes': danet_resnetd101b_cityscapes,
 
+    'fpenet_cityscapes': fpenet_cityscapes,
+
+    'ctxnet_cityscapes': ctxnet_cityscapes,
+
+    'lednet_cityscapes': lednet_cityscapes,
+
+    'esnet_cityscapes': esnet_cityscapes,
+
+    'edanet_cityscapes': edanet_cityscapes,
+
+    'enet_cityscapes': enet_cityscapes,
+
+    'erfnet_cityscapes': erfnet_cityscapes,
+
+    'linknet_cityscapes': linknet_cityscapes,
+
+    'segnet_cityscapes': segnet_cityscapes,
+
+    'unet_cityscapes': unet_cityscapes,
+
+    'sqnet_cityscapes': sqnet_cityscapes,
+
     'alphapose_fastseresnet101b_coco': alphapose_fastseresnet101b_coco,
 
     'simplepose_resnet18_coco': simplepose_resnet18_coco,
@@ -1091,11 +1145,24 @@ _models = {
     'lffd20x5s320v2_widerface': lffd20x5s320v2_widerface,
     'lffd25x8s560v1_widerface': lffd25x8s560v1_widerface,
 
+    'pfpcnet': pfpcnet,
     'voca8flame': voca8flame,
     'nvpattexp116bazel76': nvpattexp116bazel76,
 
     'superpointnet': superpointnet,
 
+    'jasper5x3': jasper5x3,
+    'jasper10x4': jasper10x4,
+    'jasper10x5': jasper10x5,
+
+    'jasperdr5x3': jasperdr5x3,
+    'jasperdr10x4': jasperdr10x4,
+    'jasperdr10x5': jasperdr10x5,
+
+    'quartznet5x5': quartznet5x5,
+    'quartznet10x5': quartznet10x5,
+    'quartznet15x5': quartznet15x5,
+
     # 'oth_pose_coco_resnet_50_256x192': oth_pose_coco_resnet_50_256x192,
     # 'oth_pose_coco_resnet_50_384x288': oth_pose_coco_resnet_50_384x288,
     # 'oth_pose_coco_resnet_101_256x192': oth_pose_coco_resnet_101_256x192,
@@ -1116,6 +1183,8 @@ _models = {
 
     # 'oth_tresnet_m': oth_tresnet_m,
     # 'tresnet_m': tresnet_m,
+
+    # 'oth_dabnet_cityscapes': oth_dabnet_cityscapes,
 }
 
 
