@@ -1,5 +1,5 @@
 """
-    DARTS, implemented in PyTorch.
+    DARTS for ImageNet-1K, implemented in PyTorch.
     Original paper: 'DARTS: Differentiable Architecture Search,' https://arxiv.org/abs/1806.09055.
 """
 
@@ -499,6 +499,8 @@ class DartsUnit(nn.Module):
         List of genotype elements (operations and linked indices).
     reduction : bool
         Whether use reduction.
+    prev_reduction : bool
+        Whether use previous reduction.
     """
     def __init__(self,
                  in_channels,
@@ -621,7 +623,7 @@ class DARTS(nn.Module):
 
 def get_darts(model_name=None,
               pretrained=False,
-              root=os.path.join('~', '.torch', 'models'),
+              root=os.path.join("~", ".torch", "models"),
               **kwargs):
     """
     Create DARTS model with specific parameters.
@@ -703,7 +705,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -721,7 +722,7 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != darts or weight_count == 4718752)
 
-        x = Variable(torch.randn(1, 3, 224, 224))
+        x = torch.randn(1, 3, 224, 224)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
