@@ -1,15 +1,17 @@
 """
-    DenseNet for CIFAR, implemented in PyTorch.
+    DenseNet for CIFAR/SVHN, implemented in PyTorch.
     Original paper: 'Densely Connected Convolutional Networks,' https://arxiv.org/abs/1608.06993.
 """
 
-__all__ = ['CIFARDenseNet', 'densenet40_k12_cifar10', 'densenet40_k12_cifar100', 'densenet40_k12_bc_cifar10',
-           'densenet40_k12_bc_cifar100', 'densenet40_k24_bc_cifar10', 'densenet40_k24_bc_cifar100',
-           'densenet40_k36_bc_cifar10', 'densenet40_k36_bc_cifar100', 'densenet100_k12_cifar10',
-           'densenet100_k12_cifar100', 'densenet100_k24_cifar10', 'densenet100_k24_cifar100',
-           'densenet100_k12_bc_cifar10', 'densenet100_k12_bc_cifar10', 'densenet100_k12_bc_cifar100',
-           'densenet190_k40_bc_cifar10', 'densenet190_k40_bc_cifar100', 'densenet250_k24_bc_cifar10',
-           'densenet250_k24_bc_cifar100']
+__all__ = ['CIFARDenseNet', 'densenet40_k12_cifar10', 'densenet40_k12_cifar100', 'densenet40_k12_svhn',
+           'densenet40_k12_bc_cifar10', 'densenet40_k12_bc_cifar100', 'densenet40_k12_bc_svhn',
+           'densenet40_k24_bc_cifar10', 'densenet40_k24_bc_cifar100', 'densenet40_k24_bc_svhn',
+           'densenet40_k36_bc_cifar10', 'densenet40_k36_bc_cifar100', 'densenet40_k36_bc_svhn',
+           'densenet100_k12_cifar10', 'densenet100_k12_cifar100', 'densenet100_k12_svhn',
+           'densenet100_k24_cifar10', 'densenet100_k24_cifar100', 'densenet100_k24_svhn',
+           'densenet100_k12_bc_cifar10', 'densenet100_k12_bc_cifar100', 'densenet100_k12_bc_svhn',
+           'densenet190_k40_bc_cifar10', 'densenet190_k40_bc_cifar100', 'densenet190_k40_bc_svhn',
+           'densenet250_k24_bc_cifar10', 'densenet250_k24_bc_cifar100', 'densenet250_k24_bc_svhn']
 
 import os
 import torch
@@ -30,7 +32,7 @@ class DenseSimpleUnit(nn.Module):
         Number of input channels.
     out_channels : int
         Number of output channels.
-    dropout_rate : bool
+    dropout_rate : float
         Parameter of Dropout layer. Faction of the input units to drop.
     """
 
@@ -141,7 +143,7 @@ def get_densenet_cifar(num_classes,
                        bottleneck,
                        model_name=None,
                        pretrained=False,
-                       root=os.path.join('~', '.torch', 'models'),
+                       root=os.path.join("~", ".torch", "models"),
                        **kwargs):
     """
     Create DenseNet model for CIFAR with specific parameters.
@@ -237,6 +239,24 @@ def densenet40_k12_cifar100(num_classes=100, **kwargs):
                               model_name="densenet40_k12_cifar100", **kwargs)
 
 
+def densenet40_k12_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-40 (k=12) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=40, growth_rate=12, bottleneck=False,
+                              model_name="densenet40_k12_svhn", **kwargs)
+
+
 def densenet40_k12_bc_cifar10(num_classes=10, **kwargs):
     """
     DenseNet-BC-40 (k=12) model for CIFAR-10 from 'Densely Connected Convolutional Networks,'
@@ -273,6 +293,24 @@ def densenet40_k12_bc_cifar100(num_classes=100, **kwargs):
                               model_name="densenet40_k12_bc_cifar100", **kwargs)
 
 
+def densenet40_k12_bc_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-BC-40 (k=12) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=40, growth_rate=12, bottleneck=True,
+                              model_name="densenet40_k12_bc_svhn", **kwargs)
+
+
 def densenet40_k24_bc_cifar10(num_classes=10, **kwargs):
     """
     DenseNet-BC-40 (k=24) model for CIFAR-10 from 'Densely Connected Convolutional Networks,'
@@ -309,6 +347,24 @@ def densenet40_k24_bc_cifar100(num_classes=100, **kwargs):
                               model_name="densenet40_k24_bc_cifar100", **kwargs)
 
 
+def densenet40_k24_bc_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-BC-40 (k=24) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=40, growth_rate=24, bottleneck=True,
+                              model_name="densenet40_k24_bc_svhn", **kwargs)
+
+
 def densenet40_k36_bc_cifar10(num_classes=10, **kwargs):
     """
     DenseNet-BC-40 (k=36) model for CIFAR-10 from 'Densely Connected Convolutional Networks,'
@@ -345,6 +401,24 @@ def densenet40_k36_bc_cifar100(num_classes=100, **kwargs):
                               model_name="densenet40_k36_bc_cifar100", **kwargs)
 
 
+def densenet40_k36_bc_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-BC-40 (k=36) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=40, growth_rate=36, bottleneck=True,
+                              model_name="densenet40_k36_bc_svhn", **kwargs)
+
+
 def densenet100_k12_cifar10(num_classes=10, **kwargs):
     """
     DenseNet-100 (k=12) model for CIFAR-10 from 'Densely Connected Convolutional Networks,'
@@ -381,6 +455,24 @@ def densenet100_k12_cifar100(num_classes=100, **kwargs):
                               model_name="densenet100_k12_cifar100", **kwargs)
 
 
+def densenet100_k12_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-100 (k=12) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=100, growth_rate=12, bottleneck=False,
+                              model_name="densenet100_k12_svhn", **kwargs)
+
+
 def densenet100_k24_cifar10(num_classes=10, **kwargs):
     """
     DenseNet-100 (k=24) model for CIFAR-10 from 'Densely Connected Convolutional Networks,'
@@ -417,6 +509,24 @@ def densenet100_k24_cifar100(num_classes=100, **kwargs):
                               model_name="densenet100_k24_cifar100", **kwargs)
 
 
+def densenet100_k24_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-100 (k=24) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=100, growth_rate=24, bottleneck=False,
+                              model_name="densenet100_k24_svhn", **kwargs)
+
+
 def densenet100_k12_bc_cifar10(num_classes=10, **kwargs):
     """
     DenseNet-BC-100 (k=12) model for CIFAR-10 from 'Densely Connected Convolutional Networks,'
@@ -453,6 +563,24 @@ def densenet100_k12_bc_cifar100(num_classes=100, **kwargs):
                               model_name="densenet100_k12_bc_cifar100", **kwargs)
 
 
+def densenet100_k12_bc_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-BC-100 (k=12) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=100, growth_rate=12, bottleneck=True,
+                              model_name="densenet100_k12_bc_svhn", **kwargs)
+
+
 def densenet190_k40_bc_cifar10(num_classes=10, **kwargs):
     """
     DenseNet-BC-190 (k=40) model for CIFAR-10 from 'Densely Connected Convolutional Networks,'
@@ -489,6 +617,24 @@ def densenet190_k40_bc_cifar100(num_classes=100, **kwargs):
                               model_name="densenet190_k40_bc_cifar100", **kwargs)
 
 
+def densenet190_k40_bc_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-BC-190 (k=40) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=190, growth_rate=40, bottleneck=True,
+                              model_name="densenet190_k40_bc_svhn", **kwargs)
+
+
 def densenet250_k24_bc_cifar10(num_classes=10, **kwargs):
     """
     DenseNet-BC-250 (k=24) model for CIFAR-10 from 'Densely Connected Convolutional Networks,'
@@ -525,6 +671,24 @@ def densenet250_k24_bc_cifar100(num_classes=100, **kwargs):
                               model_name="densenet250_k24_bc_cifar100", **kwargs)
 
 
+def densenet250_k24_bc_svhn(num_classes=10, **kwargs):
+    """
+    DenseNet-BC-250 (k=24) model for SVHN from 'Densely Connected Convolutional Networks,'
+    https://arxiv.org/abs/1608.06993.
+
+    Parameters:
+    ----------
+    num_classes : int, default 10
+        Number of classification classes.
+    pretrained : bool, default False
+        Whether to load the pretrained weights for model.
+    root : str, default '~/.torch/models'
+        Location for keeping the model parameters.
+    """
+    return get_densenet_cifar(num_classes=num_classes, blocks=250, growth_rate=24, bottleneck=True,
+                              model_name="densenet250_k24_bc_svhn", **kwargs)
+
+
 def _calc_width(net):
     import numpy as np
     net_params = filter(lambda p: p.requires_grad, net.parameters())
@@ -536,29 +700,37 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
     models = [
         (densenet40_k12_cifar10, 10),
         (densenet40_k12_cifar100, 100),
+        (densenet40_k12_svhn, 10),
         (densenet40_k12_bc_cifar10, 10),
         (densenet40_k12_bc_cifar100, 100),
+        (densenet40_k12_bc_svhn, 10),
         (densenet40_k24_bc_cifar10, 10),
         (densenet40_k24_bc_cifar100, 100),
+        (densenet40_k24_bc_svhn, 10),
         (densenet40_k36_bc_cifar10, 10),
         (densenet40_k36_bc_cifar100, 100),
+        (densenet40_k36_bc_svhn, 10),
         (densenet100_k12_cifar10, 10),
         (densenet100_k12_cifar100, 100),
+        (densenet100_k12_svhn, 10),
         (densenet100_k24_cifar10, 10),
         (densenet100_k24_cifar100, 100),
+        (densenet100_k24_svhn, 10),
         (densenet100_k12_bc_cifar10, 10),
         (densenet100_k12_bc_cifar100, 100),
+        (densenet100_k12_bc_svhn, 10),
         (densenet190_k40_bc_cifar10, 10),
         (densenet190_k40_bc_cifar100, 100),
+        (densenet190_k40_bc_svhn, 10),
         (densenet250_k24_bc_cifar10, 10),
         (densenet250_k24_bc_cifar100, 100),
+        (densenet250_k24_bc_svhn, 10),
     ]
 
     for model, num_classes in models:
@@ -571,24 +743,33 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != densenet40_k12_cifar10 or weight_count == 599050)
         assert (model != densenet40_k12_cifar100 or weight_count == 622360)
+        assert (model != densenet40_k12_svhn or weight_count == 599050)
         assert (model != densenet40_k12_bc_cifar10 or weight_count == 176122)
         assert (model != densenet40_k12_bc_cifar100 or weight_count == 188092)
+        assert (model != densenet40_k12_bc_svhn or weight_count == 176122)
         assert (model != densenet40_k24_bc_cifar10 or weight_count == 690346)
         assert (model != densenet40_k24_bc_cifar100 or weight_count == 714196)
+        assert (model != densenet40_k24_bc_svhn or weight_count == 690346)
         assert (model != densenet40_k36_bc_cifar10 or weight_count == 1542682)
         assert (model != densenet40_k36_bc_cifar100 or weight_count == 1578412)
+        assert (model != densenet40_k36_bc_svhn or weight_count == 1542682)
         assert (model != densenet100_k12_cifar10 or weight_count == 4068490)
         assert (model != densenet100_k12_cifar100 or weight_count == 4129600)
+        assert (model != densenet100_k12_svhn or weight_count == 4068490)
         assert (model != densenet100_k24_cifar10 or weight_count == 16114138)
         assert (model != densenet100_k24_cifar100 or weight_count == 16236268)
+        assert (model != densenet100_k24_svhn or weight_count == 16114138)
         assert (model != densenet100_k12_bc_cifar10 or weight_count == 769162)
         assert (model != densenet100_k12_bc_cifar100 or weight_count == 800032)
+        assert (model != densenet100_k12_bc_svhn or weight_count == 769162)
         assert (model != densenet190_k40_bc_cifar10 or weight_count == 25624430)
         assert (model != densenet190_k40_bc_cifar100 or weight_count == 25821620)
+        assert (model != densenet190_k40_bc_svhn or weight_count == 25624430)
         assert (model != densenet250_k24_bc_cifar10 or weight_count == 15324406)
         assert (model != densenet250_k24_bc_cifar100 or weight_count == 15480556)
+        assert (model != densenet250_k24_bc_svhn or weight_count == 15324406)
 
-        x = Variable(torch.randn(1, 3, 32, 32))
+        x = torch.randn(1, 3, 32, 32)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, num_classes))
