@@ -1,5 +1,5 @@
 """
-    InceptionV4, implemented in PyTorch.
+    InceptionV4 for ImageNet-1K, implemented in PyTorch.
     Original paper: 'Inception-v4, Inception-ResNet and the Impact of Residual Connections on Learning,'
     https://arxiv.org/abs/1602.07261.
 """
@@ -603,14 +603,14 @@ class InceptionV4(nn.Module):
                 stage.add_module("unit{}".format(j + 1), unit())
             self.features.add_module("stage{}".format(i + 1), stage)
 
-        self.features.add_module('final_pool', nn.AvgPool2d(
+        self.features.add_module("final_pool", nn.AvgPool2d(
             kernel_size=8,
             stride=1))
 
         self.output = nn.Sequential()
         if dropout_rate > 0.0:
-            self.output.add_module('dropout', nn.Dropout(p=dropout_rate))
-        self.output.add_module('fc', nn.Linear(
+            self.output.add_module("dropout", nn.Dropout(p=dropout_rate))
+        self.output.add_module("fc", nn.Linear(
             in_features=1536,
             out_features=num_classes))
 
@@ -632,7 +632,7 @@ class InceptionV4(nn.Module):
 
 def get_inceptionv4(model_name=None,
                     pretrained=False,
-                    root=os.path.join('~', '.torch', 'models'),
+                    root=os.path.join("~", ".torch", "models"),
                     **kwargs):
     """
     Create InceptionV4 model with specific parameters.
@@ -687,7 +687,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -704,7 +703,7 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != InceptionV4 or weight_count == 42679816)
 
-        x = Variable(torch.randn(1, 3, 299, 299))
+        x = torch.randn(1, 3, 299, 299)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
